@@ -18,10 +18,13 @@ use getset::Getters;
 
 #[derive(Debug, Clone, Deserialize, Serialize, Constructor, Getters)]
 #[serde(deny_unknown_fields)]
+/// initialization and job specification for python job batches
 pub struct Description<FILE> {
     #[getset(get = "pub(crate)")]
+    /// initialization information on how to compile the job batch
     pub initialize: Initialize<FILE>,
     #[getset(get = "pub(crate)")]
+    /// list of jobs to execute with the given initialization
     pub jobs: Vec<Job<FILE>>,
 }
 
@@ -48,9 +51,7 @@ impl Description<common::File> {
         self.jobs.len()
     }
 
-    pub(super) fn hashed(
-        &self,
-    ) -> Result<Description<common::HashedFile>, super::MissingFilename> {
+    pub(super) fn hashed(&self) -> Result<Description<common::HashedFile>, super::MissingFilename> {
         let initialize = self.initialize.hashed()?;
 
         let mut jobs = Vec::new();
@@ -109,20 +110,21 @@ where
 
 #[derive(Debug, Clone, Deserialize, Serialize, Constructor, getset::Getters)]
 #[serde(deny_unknown_fields)]
+/// initialization information for python jobs
 pub struct Initialize<FILE> {
     #[serde(rename = "build_file")]
     #[getset(get = "pub(crate)")]
+    /// path to build file for python job batch
     pub python_build_file_path: FILE,
     #[serde(default = "Default::default")]
     #[getset(get = "pub(crate)")]
+    /// list of required files used in compilation script
     pub(super) required_files: Vec<FILE>,
 }
 
 #[cfg(feature = "cli")]
 impl Initialize<common::File> {
-    pub(crate) fn hashed(
-        &self,
-    ) -> Result<Initialize<common::HashedFile>, super::MissingFilename> {
+    pub(crate) fn hashed(&self) -> Result<Initialize<common::HashedFile>, super::MissingFilename> {
         let init_hash = hashing::filename_hash(self);
 
         let hashed_path = format!("setup_python_{init_hash}.dist").into();
@@ -169,6 +171,7 @@ impl Initialize<common::HashedFile> {
 
 #[derive(Debug, Clone, Deserialize, Serialize, Constructor, getset::Getters)]
 #[serde(deny_unknown_fields)]
+/// specification for a python job
 pub struct Job<FILE> {
     #[getset(get = "pub(crate)")]
     pub(super) name: String,
@@ -178,9 +181,9 @@ pub struct Job<FILE> {
     #[serde(default = "Default::default")]
     #[getset(get = "pub(crate)")]
     pub(super) required_files: Vec<FILE>,
-    /// slurm configuration. This level of information will override the defeaults at the outer 
+    /// slurm configuration. This level of information will override the defeaults at the outer
     /// most level of the configuration
-    slurm: Option<super::Slurm>
+    slurm: Option<super::Slurm>,
 }
 
 #[cfg(feature = "cli")]
@@ -221,7 +224,7 @@ impl Job<common::File> {
             name: self.name().to_string(),
             python_job_file,
             required_files,
-            slurm: self.slurm.clone()
+            slurm: self.slurm.clone(),
         };
 
         Ok(job)
