@@ -3,6 +3,7 @@ use super::cli::Template;
 use crate::config::{self, apptainer, common, python};
 use crate::error::{Error, TemplateError};
 
+/// create a `distribute-jobs.yaml` with some default fields
 pub fn template(args: Template) -> Result<(), Error> {
     let out = to_template(args.mode)?;
 
@@ -38,7 +39,7 @@ fn python_template() -> Result<String, TemplateError> {
                 "input.json",
             ),
         ],
-        None
+        None,
     );
 
     let python = python::Description::new(initialize, vec![job_1]);
@@ -82,7 +83,8 @@ fn apptainer_template() -> Result<String, TemplateError> {
 
     // TODO: better slurm defaults
     let slurm = None;
-    let desc: config::Jobs<common::File> = config::ApptainerConfig::new(meta, apptainer, slurm).into();
+    let desc: config::Jobs<common::File> =
+        config::ApptainerConfig::new(meta, apptainer, slurm).into();
     let serialized = serde_yaml::to_string(&desc)?;
 
     Ok(serialized)
